hs_expr_ext

Struct hs_expr_ext 

#[repr(C)]
pub struct hs_expr_ext { pub flags: c_ulonglong, pub min_offset: c_ulonglong, pub max_offset: c_ulonglong, pub min_length: c_ulonglong, pub edit_distance: c_uint, pub hamming_distance: c_uint, }
A structure containing additional parameters related to an expression, passed in at build time to @ref hs_compile_ext_multi() or @ref hs_expression_ext_info.

These parameters allow the set of matches produced by a pattern to be constrained at compile time, rather than relying on the application to process unwanted matches at runtime.

Fields

flags: c_ulonglong

Flags governing which parts of this structure are to be used by the compiler. See @ref HS_EXT_FLAG.

min_offset: c_ulonglong

The minimum end offset in the data stream at which this expression should match successfully. To use this parameter, set the @ref HS_EXT_FLAG_MIN_OFFSET flag in the hs_expr_ext::flags field.

max_offset: c_ulonglong

The maximum end offset in the data stream at which this expression should match successfully. To use this parameter, set the @ref HS_EXT_FLAG_MAX_OFFSET flag in the hs_expr_ext::flags field.

min_length: c_ulonglong

The minimum match length (from start to end) required to successfully match this expression. To use this parameter, set the @ref HS_EXT_FLAG_MIN_LENGTH flag in the hs_expr_ext::flags field.

edit_distance: c_uint

Allow patterns to approximately match within this edit distance. To use this parameter, set the @ref HS_EXT_FLAG_EDIT_DISTANCE flag in the hs_expr_ext::flags field.

hamming_distance: c_uint

Allow patterns to approximately match within this Hamming distance. To use this parameter, set the @ref HS_EXT_FLAG_HAMMING_DISTANCE flag in the hs_expr_ext::flags field.