hs_expr_info

Struct hs_expr_info 

#[repr(C)]
pub struct hs_expr_info { pub min_width: c_uint, pub max_width: c_uint, pub unordered_matches: c_char, pub matches_at_eod: c_char, pub matches_only_at_eod: c_char, }
A type containing information related to an expression that is returned by @ref hs_expression_info() or @ref hs_expression_ext_info.

Fields

min_width: c_uint

The minimum length in bytes of a match for the pattern.

Note: in some cases when using advanced features to suppress matches (such as extended parameters or the @ref HS_FLAG_SINGLEMATCH flag) this may represent a conservative lower bound for the true minimum length of a match.

max_width: c_uint

The maximum length in bytes of a match for the pattern. If the pattern has an unbounded maximum length, this will be set to the maximum value of an unsigned int (UINT_MAX).

Note: in some cases when using advanced features to suppress matches (such as extended parameters or the @ref HS_FLAG_SINGLEMATCH flag) this may represent a conservative upper bound for the true maximum length of a match.

unordered_matches: c_char

Whether this expression can produce matches that are not returned in order, such as those produced by assertions. Zero if false, non-zero if true.

matches_at_eod: c_char

Whether this expression can produce matches at end of data (EOD). In streaming mode, EOD matches are raised during @ref hs_close_stream(), since it is only when @ref hs_close_stream() is called that the EOD location is known. Zero if false, non-zero if true.

Note: trailing \b word boundary assertions may also result in EOD matches as end-of-data can act as a word boundary.

matches_only_at_eod: c_char

Whether this expression can only produce matches at end of data (EOD). In streaming mode, all matches for this expression are raised during @ref hs_close_stream(). Zero if false, non-zero if true.