hs_platform_info

Struct hs_platform_info 

#[repr(C)]
pub struct hs_platform_info { pub tune: c_uint, pub cpu_features: c_ulonglong, pub reserved1: c_ulonglong, pub reserved2: c_ulonglong, }
A type containing information on the target platform which may optionally be provided to the compile calls (@ref hs_compile(), @ref hs_compile_multi(), @ref hs_compile_ext_multi()).

A hs_platform_info structure may be populated for the current platform by using the @ref hs_populate_platform() call.

Fields

tune: c_uint

Information about the target platform which may be used to guide the optimisation process of the compile.

Use of this field does not limit the processors that the resulting database can run on, but may impact the performance of the resulting database.

cpu_features: c_ulonglong

Relevant CPU features available on the target platform

This value may be produced by combining HS_CPU_FEATURE_* flags (such as @ref HS_CPU_FEATURES_AVX2). Multiple CPU features may be or’ed together to produce the value.

reserved1: c_ulonglong

Reserved for future use.

reserved2: c_ulonglong

Reserved for future use.